==> haskell-ipython-kernel-0.11.0.0-168.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-KSTHHMXmY8mCgaUMOuN0el
key:                  ipython-kernel-0.11.0.0-KSTHHMXmY8mCgaUMOuN0el
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  fcc9497983f32008da7e3cab2d7b3769
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-KSTHHMXmY8mCgaUMOuN0el
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LM2EJiGJsV242NzdXbkugt directory-1.3.8.5
    filepath-1.4.300.1 memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    parsec-3.1.16.1 process-1.6.19.0
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
    zeromq4-haskell-0.8.0-ChCGqWfwfEcNKZlf5SSRg

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipython-kernel-0.11.0.0-169-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-JY887qs95p2K1HRIFm7l4W
key:                  ipython-kernel-0.11.0.0-JY887qs95p2K1HRIFm7l4W
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  30ed1367fca020537d91acac10eafc31
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-JY887qs95p2K1HRIFm7l4W
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-5QYVWJr24zH1Zlsr0wVxCr directory-1.3.8.5
    filepath-1.4.300.1 memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    parsec-3.1.16.1 process-1.6.19.0
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
    zeromq4-haskell-0.8.0-FkThmOtI74XafZt2ovDui

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
